# Pilli

The whistle (Finnish: pilli, German: Der Pfiff) parsing random DAFIF like data. 

[License: MIT](https://git.sr.ht/~sthagen/pilli/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/pilli.svg?style=flat)](https://pypi.python.org/pypi/pilli/)
[![downloads](https://img.shields.io/pypi/dm/pilli.svg?style=flat)](https://pypi.python.org/pypi/pilli/)
[![wheel](https://img.shields.io/pypi/wheel/pilli.svg?style=flat)](https://pypi.python.org/pypi/pilli/)
[![supported-versions](https://img.shields.io/pypi/pyversions/pilli.svg?style=flat)](https://pypi.python.org/pypi/pilli/)
[![supported-implementations](https://img.shields.io/pypi/implementation/pilli.svg?style=flat)](https://pypi.python.org/pypi/pilli/)

## Documentation

User and developer [documentation of pilli](https://codes.dilettant.life/docs/pilli).

## Bug Tracker

Feature requests and bug reports are bested entered in the [todos of pilli](https://todo.sr.ht/~sthagen/pilli).

## Primary Source repository

The primary source repository of [pilli is at sourcehut](https://git.sr.ht/~sthagen/pilli)
a collection of tools useful for software development.

## Status

Experimental.

**Note**: The default branch is `default`.
